@@ -3,7 +3,7 @@ package Protocol::WebSocket;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.16';
 
 use Protocol::WebSocket::Frame;
 use Protocol::WebSocket::Handshake::Client;
@@ -114,13 +114,19 @@ Chuck Bredestege
 
 Matthew Lien (BlueT)
 
+Joao Orui
+
+Toshio Ito (debug-ito)
+
+Neil Bowers
+
 =head1 AUTHOR
 
 Viacheslav Tykhanovskyi, C<vti@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2010-2012, Viacheslav Tykhanovskyi.
+Copyright (C) 2010-2013, Viacheslav Tykhanovskyi.
 
 This program is free software, you can redistribute it and/or modify it under
 the same terms as Perl 5.10.
